# PyDataVec : Python interface for DataVec

## Installation

```bash
pip install pydatavec
```

## Examples

Examples are in the [dl4j-examples repo](www.github.com/deeplearning4j/dl4j-examples)

Clone dl4j-examples:

```bash
git clone https://www.github.com/deeplearning4j.dl4j-examples.git
```

Run examples in `pydatavec-examples` directory

```bash
cd pydatavec-examples
python basic.py
python iris.py
python reduction.py
```

